@@ -41,15 +41,19 @@ fn create_runtime_snapshot(snapshot_path: &Path, files: Vec<PathBuf>) {
     deno_webidl::init(),
     deno_console::init(),
     deno_url::init(),
+    deno_tls::init(),
     deno_web::init(deno_web::BlobStore::default(), Default::default()),
     deno_fetch::init::<deno_fetch::NoFetchPermissions>(
       "".to_owned(),
       None,
       None,
+      None,
+      None,
     ),
     deno_websocket::init::<deno_websocket::NoWebSocketPermissions>(
       "".to_owned(),
       None,
+      None,
     ),
     deno_webstorage::init(None),
     deno_crypto::init(None),
@@ -59,7 +63,11 @@ fn create_runtime_snapshot(snapshot_path: &Path, files: Vec<PathBuf>) {
       deno_broadcast_channel::InMemoryBroadcastChannel::default(),
       false, // No --unstable.
     ),
-    deno_net::init::<deno_net::NoNetPermissions>(None, false), // No --unstable.
+    deno_ffi::init::<deno_ffi::NoFfiPermissions>(false),
+    deno_net::init::<deno_net::NoNetPermissions>(
+      None, false, // No --unstable.
+      None,
+    ),
     deno_http::init(),
   ];
 
@@ -72,11 +80,6 @@ fn create_runtime_snapshot(snapshot_path: &Path, files: Vec<PathBuf>) {
 }
 
 fn main() {
-  // Skip building from docs.rs.
-  if env::var_os("DOCS_RS").is_some() {
-    return;
-  }
-
   // To debug snapshot issues uncomment:
   // op_fetch_asset::trace_serializer();
 
@@ -87,6 +90,15 @@ fn main() {
   // Main snapshot
   let runtime_snapshot_path = o.join("CLI_SNAPSHOT.bin");
 
+  // If we're building on docs.rs we just create
+  // and empty snapshot file and return, because `rusty_v8`
+  // doesn't actually compile on docs.rs
+  if env::var_os("DOCS_RS").is_some() {
+    let snapshot_slice = &[];
+    std::fs::write(&runtime_snapshot_path, snapshot_slice).unwrap();
+    return;
+  }
+
   let js_files = get_js_files("js");
   create_runtime_snapshot(&runtime_snapshot_path, js_files);
 }
